@@ -17,6 +17,9 @@ from pathlib import Path
 CSI_RE = re.compile(r"\x1b\[[0-9;?]*[ -/]*[@-~]")
 OSC_RE = re.compile(r"\x1b\].*?(?:\x07|\x1b\\)")
 RGB_RE = re.compile(r"(?:rgb:|gb:)[0-9a-fA-F]{4}/[0-9a-fA-F]{4}/[0-9a-fA-F]{4}")
+ITERM_OK_RE = re.compile(r"[>|\\s]*iTerm2\\s+[^;]*;OK")
+ITERM_GI_RE = re.compile(r"Gi=31337;OK")
+ITERM_PREFIX_RE = re.compile(r"[>|\\s]*iTerm2\\s+[0-9.]+/?")
 
 
 def now_iso():
@@ -152,6 +155,9 @@ def strip_ansi(text):
 def sanitize_text(text):
     text = strip_ansi(text)
     text = RGB_RE.sub("", text)
+    text = ITERM_OK_RE.sub("", text)
+    text = ITERM_GI_RE.sub("", text)
+    text = ITERM_PREFIX_RE.sub("", text)
     text = "".join(ch for ch in text if ch >= " " and ch != "\x7f")
     return text.strip()
 
